componenttools.Component
========================

.. abjad-lineage:: abjad.tools.componenttools.Component.Component.Component

.. autoclass:: abjad.tools.componenttools.Component.Component.Component

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.componenttools.Component.Component.Component.lilypond_format
      ~abjad.tools.componenttools.Component.Component.Component.override
      ~abjad.tools.componenttools.Component.Component.Component.select
      ~abjad.tools.componenttools.Component.Component.Component.set
      ~abjad.tools.componenttools.Component.Component.Component.storage_format
      ~abjad.tools.componenttools.Component.Component.Component.__copy__
      ~abjad.tools.componenttools.Component.Component.Component.__eq__
      ~abjad.tools.componenttools.Component.Component.Component.__mul__
      ~abjad.tools.componenttools.Component.Component.Component.__ne__
      ~abjad.tools.componenttools.Component.Component.Component.__repr__
      ~abjad.tools.componenttools.Component.Component.Component.__rmul__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.override
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.set
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.componenttools.Component.Component.Component.select
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__copy__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__eq__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__mul__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__ne__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__repr__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__rmul__
   :noindex:
